@@ -1,6 +1,6 @@
-## Domain Registry Interface, Gandi Registry Driver
+## Domain Registry Interface, Gandi Registry Driver for .COM, .NET, .ORG, .INFO, .BIZ, .NAME, .BE
 ##
-## Copyright (c) 2005,2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,28 +10,31 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::DRD::Gandi;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::DRD::Gandi - Gandi Registry driver for Net::DRI
+Net::DRI::DRD::Gandi - Gandi .COM/.NET/.ORG/.BIZ/.INFO/.NAME/.BE Registry driver for Net::DRI
 
 =head1 DESCRIPTION
 
 Please see the README file for details.
 
-=head1 CURRENT LIMITATIONS
+=head2 CURRENT LIMITATIONS
 
-Only domain_info and account_list_domains are implemented for now
+Only domain_update_ns_* are provided
 
 =head1 SUPPORT
 
@@ -51,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008,2009,2011 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,28 +66,44 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 #####################################################################################
 
-sub name         { return 'Gandi'; }
+sub is_thick     { return 1; }
+sub name         { return "Gandi"; }
 sub tlds         { return ('com','net','org','biz','info','name','be'); }
-sub object_types { return ('domain','contact'); }
-sub profile_types { return qw/ws/; }
 
-sub transport_protocol_default
+sub transport_protocol_compatible 
 {
- my ($self,$type)=@_;
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
 
- return ('Net::DRI::Transport::HTTP::XMLRPCLite',{proxy_uri=>'https://api.gandi.net/xmlrpc/'},'Net::DRI::Protocol::Gandi::WS',{}) if $type eq 'ws';
- return;
+ return 1 if (($pn eq 'gandi_web') && ($tn eq 'web'));
+ return undef;
 }
 
-####################################################################################################
+######################################################################################
+
+sub verify_name_domain
+{
+ my ($self,$ndr,$domain)=@_;
+ $domain=$ndr unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 0;
+}
 
 sub domain_operation_needs_is_mine
 {
  my ($self,$ndr,$domain,$op)=@_;
- return;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return undef;
 }
 
-####################################################################################################
+######################################################################################
 1;
