@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP E.164 Number Mapping (RFC4114)
 ##
-## Copyright (c) 2005-2009,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::E164;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $NS='urn:ietf:params:xml:ns:e164epp-1.0';
+
 =pod
 
 =head1 NAME
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2009,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,30 +65,21 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+###################################################################################################
 
 sub register_commands
 {
  my ($class,$version)=@_;
- state $domain = {
-                  info   => [ undef, \&info_parse ],
-                  create => [ \&create, undef ],
-                  update => [ \&update, undef ],
-                 };
- state $commands = { 'domain' => $domain };
- return $commands;
+ my %tmp=(
+           info   => [ undef, \&info_parse ],
+           create => [ \&create, undef ],
+           update => [ \&update, undef ],
+         );
+
+ return { 'domain' => \%tmp };
 }
 
-sub setup
-{
- my ($class,$po,$version)=@_;
- $po->ns({ 'e164' => 'urn:ietf:params:xml:ns:e164epp-1.0' });
- return;
-}
-
-sub capabilities_add { return ('domain_update','e164',['add','del']); }
-
-####################################################################################################
+###################################################################################################
 
 sub format_naptr
 {
@@ -119,7 +114,8 @@ sub format_naptr
  return @c;
 }
 
-####################################################################################################
+##################################################################################################
+
 ########### Query commands
 
 sub info_parse
@@ -128,26 +124,28 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension('e164', 'infData');
- return unless defined $infdata;
+ my $infdata=$mes->get_content('infData',$NS,1);
+ return unless $infdata;
 
  my @naptr;
- foreach my $el ($infdata->getChildrenByTagNameNS($mes->ns('e164'), 'naptr'))
+ foreach my $el ($infdata->getElementsByTagNameNS($NS,'naptr'))
  {
+  my $c=$el->firstChild();
   my %n;
-  foreach my $sel (Net::DRI::Util::xml_list_children($el))
+  while ($c)
   {
-   my ($name,$c)=@$sel;
-   if ($name=~m/^(order|pref|flags|svc|regex|replacement)$/)
+   my $name=$c->nodeName();
+   next unless $name;
+   if ($name=~m/^e164:(order|pref|flags|svc|regex|replacement)$/)
    {
-    $n{$1}=$c->textContent();
+    $n{$1}=$c->firstChild->getData();
    }
+   $c=$c->getNextSibling();
   }
   push @naptr,\%n;
  }
 
  $rinfo->{domain}->{$oname}->{e164}=\@naptr;
- return;
 }
 
 ############ Transform commands
@@ -155,37 +153,33 @@ sub info_parse
 sub create
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
- my $def=$epp->default_parameters();
-
- ## IENUMAT works without the e164 extension part
- unless (exists($rd->{e164}) && (ref($rd->{e164}) eq 'ARRAY') && @{$rd->{e164}})
- {
-  Net::DRI::Exception::usererr_insufficient_parameters('One or more E164 data block must be provided') unless (defined($def) && exists($def->{rfc4114_relax}) && $def->{rfc4114_relax});
-  return;
- }
+ Net::DRI::Exception::usererr_insufficient_parameters('One or more E164 data block must be provided') unless (exists($rd->{e164}) && (ref($rd->{e164}) eq 'ARRAY') && @{$rd->{e164}});
 
+ my $eid=$mes->command_extension_register('e164:create','xmlns:e164="urn:ietf:params:xml:ns:e164epp-1.0" xsi:schemaLocation="urn:ietf:params:xml:ns:e164epp-1.0 e164epp-1.0.xsd"');
  my @n=map { ['e164:naptr',format_naptr($_)] } (@{$rd->{e164}});
- $epp->message()->command_extension('e164', ['create', @n]);
- return;
+ $mes->command_extension($eid,\@n);
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
+ my $mes=$epp->message();
 
  my $toadd=$todo->add('e164');
  my $todel=$todo->del('e164');
 
- return unless defined $toadd || defined $todel;
+ return unless (defined($toadd) || defined($todel));
 
+ my $eid=$mes->command_extension_register('e164:update','xmlns:e164="urn:ietf:params:xml:ns:e164epp-1.0" xsi:schemaLocation="urn:ietf:params:xml:ns:e164epp-1.0 e164epp-1.0.xsd"');
+ 
  my @n;
  push @n,['e164:add',map { ['e164:naptr',format_naptr($_)] } (ref($toadd) eq 'ARRAY')? @$toadd : ($toadd)] if (defined($toadd));
  push @n,['e164:rem',map { ['e164:naptr',format_naptr($_)] } (ref($todel) eq 'ARRAY')? @$todel : ($todel)] if (defined($todel));
 
- $epp->message()->command_extension('e164', ['update', @n]);
- return;
+ $mes->command_extension($eid,\@n);
 }
 
-####################################################################################################
+#########################################################################################################
 1;
