@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EPP NSgroup extension commands
 ## (based on .BE Registration_guidelines_v4_7_1)
 ##
-## Copyright (c) 2005-2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,15 +11,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::NSgroup;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
+use Net::DRI::Data::Hosts;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $NS='http://www.dns.be/xml/epp/nsgroup-1.0';
 
 =pod
 
@@ -49,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,7 +67,8 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+
+##########################################################
 
 sub register_commands
 {
@@ -78,67 +85,65 @@ sub register_commands
  return { 'nsgroup' => \%tmp1 };
 }
 
-sub capabilities_add { return ('nsgroup_update','ns',['set']); }
-
-sub ns
+sub capabilities_add
 {
- my ($mes)=@_;
- my $ns=$mes->ns('nsgroup');
- return defined $ns? $ns : 'http://www.dns.be/xml/epp/nsgroup-1.0';
+ return { 'nsgroup_update' => { 'ns' => ['set'] } };
 }
 
 sub build_command
 {
- my ($epp,$msg,$command,$hosts)=@_;
+ my ($msg,$command,$hosts)=@_;
 
  my @gn;
- foreach my $h ( grep { defined } (ref $hosts eq 'ARRAY')? @$hosts : ($hosts))
+ foreach my $h ( grep { defined } (ref($hosts) eq 'ARRAY')? @$hosts : ($hosts))
  {
-  my $gn=Net::DRI::Util::isa_nsgroup($h)? $h->name() : $h;
-  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid NSgroup name: '.$gn) unless (defined $gn && $gn && ! ref $gn && Net::DRI::Util::xml_is_normalizedstring($gn,1,100));
+  my $gn=UNIVERSAL::isa($h,'Net::DRI::Data::Hosts')? $h->name() : $h;
+  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid NSgroup name: '.$gn) unless ($gn && Net::DRI::Util::xml_is_normalizedstring($gn,1,100));
   push @gn,$gn;
  }
 
  Net::DRI::Exception->die(1,'protocol/EPP',2,'NSgroup name needed') unless @gn;
- $msg->command([$command,'nsgroup:'.$command, $msg->nsattrs('nsgroup')]);
+
+ $msg->command([$command,'nsgroup:'.$command,'xmlns:nsgroup="http://www.dns.be/xml/epp/nsgroup-1.0" xsi:schemaLocation="http://www.dns.be/xml/epp/nsgroup-1.0 nsgroup-1.0.xsd"']);
+
  return map { ['nsgroup:name',$_] } @gn;
 }
 
 sub add_nsname
 {
  my ($ns)=@_;
- return () unless defined $ns;
- my @names;
- if (! ref $ns)
+ return () unless (defined($ns));
+ my @a;
+ if (! ref($ns))
  {
-  @names=($ns);
- } elsif (ref $ns eq 'ARRAY')
+  @a=($ns);
+ } elsif (ref($ns) eq 'ARRAY')
  {
-  @names=@$ns;
- } elsif (Net::DRI::Util::isa_nsgroup($ns))
+  @a=@$ns;
+ } elsif (UNIVERSAL::isa($ns,'Net::DRI::Data::Hosts'))
  {
-  @names=$ns->get_names();
+  @a=$ns->get_names();
  }
 
- foreach my $n (@names)
+ foreach my $n (@a) 
  {
   next if Net::DRI::Util::is_hostname($n);
   Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid host name: '.$n);
  }
 
- return map { ['nsgroup:ns',$_] } @names;
+ return map { ['nsgroup:ns',$_] } @a;
 }
 
-####################################################################################################
+
+##################################################################################################
 ########### Query commands
 
 sub check
 {
- my ($epp,@hosts)=@_;
+ my ($epp,$hosts)=@_;
  my $mes=$epp->message();
- my @d=build_command($epp,$mes,'check',\@hosts);
+ my @d=build_command($mes,'check',$hosts);
  $mes->command_body(\@d);
- return;
 }
 
 sub check_parse
@@ -147,34 +152,31 @@ sub check_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $ns=$mes->ns('nsgroup');
- my $chkdata=$mes->get_response('nsgroup', 'chkData');
- return unless defined $chkdata;
-
- foreach my $cd ($chkdata->getChildrenByTagNameNS($ns,'cd'))
+ my $chkdata=$mes->get_content('chkData',$NS);
+ return unless $chkdata;
+ foreach my $cd ($chkdata->getElementsByTagNameNS($NS,'cd'))
  {
+  my $c=$cd->firstChild;
   my $nsgroup;
-  foreach my $el (Net::DRI::Util::xml_list_children($cd))
+  while($c)
   {
-   my ($n,$c)=@$el;
-   if ($n eq 'name')
+   my $n=$c->nodeName();
+   if ($n eq 'nsgroup:name')
    {
-    $nsgroup=$c->textContent();
+    $nsgroup=$c->firstChild->getData();
     $rinfo->{nsgroup}->{$nsgroup}->{exist}=1-Net::DRI::Util::xml_parse_boolean($c->getAttribute('avail'));
-    $rinfo->{nsgroup}->{$nsgroup}->{action}='check';
    }
+   $c=$c->getNextSibling();
   }
  }
- return;
 }
 
 sub info
 {
  my ($epp,$hosts)=@_;
  my $mes=$epp->message();
- my @d=build_command($epp,$mes,'info',$hosts);
+ my @d=build_command($mes,'info',$hosts);
  $mes->command_body(\@d);
- return;
 }
 
 sub info_parse
@@ -183,27 +185,29 @@ sub info_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_response('nsgroup', 'infData');
- return unless defined $infdata;
+ my $infdata=$mes->get_content('infData',$NS);
+ return unless $infdata;
 
- my $ns=$po->create_local_object('hosts');
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ my $ns=Net::DRI::Data::Hosts->new();
+
+ my $c=$infdata->firstChild();
+ while ($c)
  {
-  my ($name,$c)=@$el;
-  if ($name eq 'name')
+  my $name=$c->nodeName();
+  next unless $name;
+  if ($name eq 'nsgroup:name')
   {
-   $oname=$c->textContent();
-   $ns->name($oname);
-   $rinfo->{nsgroup}->{$oname}->{exist}=1;
-   $rinfo->{nsgroup}->{$oname}->{action}='info';
-  } elsif ($name eq 'ns')
+   my $nsgroup=$c->firstChild->getData();
+   $ns->name($nsgroup);
+   $rinfo->{nsgroup}->{$nsgroup}->{exist}=1; ## $oname='session' here, will be fixed later (in fact not, because of change in Message, but this is temporary)
+  } elsif ($name eq 'nsgroup:ns')
   {
-   $ns->add($c->textContent());
+   $ns->add($c->firstChild->getData());
   }
+  $c=$c->getNextSibling();
  }
 
  $rinfo->{nsgroup}->{$oname}->{self}=$ns;
- return;
 }
 
 ############ Transform commands
@@ -212,19 +216,17 @@ sub create
 {
  my ($epp,$hosts)=@_;
  my $mes=$epp->message();
- my @d=build_command($epp,$mes,'create',$hosts);
+ my @d=build_command($mes,'create',$hosts);
  push @d,add_nsname($hosts);
  $mes->command_body(\@d);
- return;
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub delete
 {
  my ($epp,$hosts)=@_;
  my $mes=$epp->message();
- my @d=build_command($epp,$mes,'delete',$hosts);
+ my @d=build_command($mes,'delete',$hosts);
  $mes->command_body(\@d);
- return;
 }
 
 sub update
@@ -232,7 +234,7 @@ sub update
  my ($epp,$hosts,$todo)=@_;
  my $mes=$epp->message();
 
- Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
+ Net::DRI::Exception::usererr_invalid_parameters($todo." must be a Net::DRI::Data::Changes object") unless ($todo && UNIVERSAL::isa($todo,'Net::DRI::Data::Changes'));
 
  if ((grep { ! /^(?:ns)$/ } $todo->types()) || (grep { ! /^(?:set)$/ } $todo->types('ns') ))
  {
@@ -240,10 +242,10 @@ sub update
  }
 
  my $ns=$todo->set('ns');
- my @d=build_command($epp,$mes,'update',$hosts);
+ 
+ my @d=build_command($mes,'update',$hosts);
  push @d,add_nsname($ns);
  $mes->command_body(\@d);
- return;
 }
 
 ####################################################################################################
